Function CreateSession($path)
{
    $cred = Get-Credential
    $session = New-PSSession -ConfigurationName Microsoft.Exchange -ConnectionUri $path -Credential $cred -Authentication Basic -AllowRedirection
    $importresults = Import-PSSession $session
}

Function GrantApplicationImpersonationToServiceUser($user)
{
  $result = Get-ManagementRoleAssignment -RoleAssignee $user -Role ApplicationImpersonation -RoleAssigneeType user
  If (! $result.count -gt 0)
  {
    New-ManagementRoleAssignment -Name:impersonationAssignmentName -Role:ApplicationImpersonation -User:$user
  }
}

Function GrantUserAccessToMailbox($user, $mailbox)
{
    Get-Mailbox -identity $mailbox | Add-MailboxPermission -User:$user -AccessRights: FullAccess -InheritanceType: All
}

Function CalendarProcessing($mailbox)
{ 
    Set-CalendarProcessing $mailbox -AutomateProcessing AutoAccept -AddOrganizerToSubject $false -DeleteSubject $false
}

Function Select-FileDialog
{
	param([string]$Title,[string]$Directory,[string]$Filter="All Files (*.*)|*.*")
	[System.Reflection.Assembly]::LoadWithPartialName("System.Windows.Forms") | Out-Null
	$objForm = New-Object System.Windows.Forms.OpenFileDialog
	$objForm.InitialDirectory = $Directory
	$objForm.Filter = $Filter
	$objForm.Title = $Title
    $objForm.ShowHelp = $true
	$Show = $objForm.ShowDialog()
	If ($Show -eq "OK")
	{
		Return $objForm.FileName
	}
	Else
	{
		Write-Error "Operation cancelled by user."
	}
}
$ErrorActionPreference = "Inquire"

Function Execute
{
		
    Param(
    [parameter(Mandatory=$true, HelpMessage="The PowerShell session URI. It defaults to https://ps.outlook.com/powershell")]
    $PowerShellPath,
    [parameter(Mandatory=$true, HelpMessage="The user who will be given full access to the room mailboxes")]
    $User,
    [parameter(Mandatory=$true, HelpMessage="Room Mailbox Name")]    
    $Mailbox,
    [parameter(HelpMessage="CSV file containing a new line delimited list of rooms")]
    $CSV
    )
    
    if([string]::IsNullOrEmpty($PowerShellPath)) { $PowerShellPath = "https://ps.outlook.com/powershell" }
    
    CreateSession $PowerShellPath
    GrantApplicationImpersonationToServiceUser $User
    
    if($Mailbox)
    {
        GrantUserAccessToMailbox $User $Mailbox | CalendarProcessing $Mailbox
    }
    else
    {
        $CSV = Select-FileDialog   
        Import-Csv $CSV | ForEach-Object { GrantUserAccessToMailbox $User $_.rooms | Set-CalendarProcessing $_.mailbox -AutomateProcessing AutoAccept -AddOrganizerToSubject $false -DeleteSubject $false}
    }
    Write-Host "Press any key to continue ..."
    $x = $host.UI.RawUI.ReadKey("NoEcho,IncludeKeyDown")
}

Clear-Host

Write-Output "Definitions of values to input:"
Write-Output ""
Write-Output "   PowerShellPath:  Path to the Exchange Management shell.  Default is https://ps.outlook.com/powershell"
Write-Output ""
Write-Output "   User:  The Service account which will be given full access to the room mailboxes."
Write-Output ""
Write-Output "   Mailbox: Room Mailbox Name (or press enter to use a CSV file)"
Write-Output ""
Write-Output "   When challenged for credentials, enter User name and Password for a user with Exchange Admin rights."
Write-Output ""
Write-Output "   CSV: file selection dialog will be displayed."

Start-Sleep -Seconds 5

Execute